@@ -62,7 +62,7 @@ public:
 	virtual ~magickpp_trgt();
 
 	virtual bool set_rend_desc(synfig::RendDesc *desc);
-	virtual bool init();
+	virtual bool init(synfig::ProgressCallback *cb);
 
 	virtual bool start_frame(synfig::ProgressCallback *cb);
 	virtual void end_frame();
